# Tutorials & Guides (UNFINISHED)

<!--
SELF NOTE:

I like these card-type templates:
- [ramanspy tutorials](https://ramanspy.readthedocs.io/en/latest/auto_tutorials/index.html)
- [cartopy gallery](https://scitools.org.uk/cartopy/docs/latest/gallery/index.html)
-->

## [1] Getting Started


<div class="grid cards" markdown>

-   [**:octicons-arrow-right-24: How to Install/Use Python**](./getting_started/install_python.md)

    <figure markdown="span">
        [![](https://external-content.duckduckgo.com/iu/?u=https%3A%2F%2Fwww.marinedatascience.co%2Fimg%2Fsoftware%2Flogo_python.png&f=1&nofb=1&ipt=9f5fada5e7a9373fa22793ffdd86ea19d68a11808a4f228db22bc1d2ffc32654&ipo=images){ width="100" }](./getting_started/install_python.md)
    </figure>

    Overview of concepts, tools, and practices for installing Python and managing packages.

-   [**:octicons-arrow-right-24: Online Demo**](./getting_started/online_demo.md)

    <figure markdown="span">
        [![](https://avatars.githubusercontent.com/u/33467679?s=280&v=4){ width="100" }](./getting_started/online_demo.md)
    </figure>

    Try RedPlanet in your browser without installing anything.

</div>



&nbsp;

---
## [2] Advanced


<div class="grid cards" markdown>

-   [**:octicons-arrow-right-24: Radial Profiles**](./analysis/radial_profile.md)

    <figure markdown="span">
        [![](https://files.catbox.moe/7ehom0.png){ width="200" }](./analysis/radial_profile.md)
    </figure>

    Average cross-section of a crater.

-   More coming soon!

</div>



&nbsp;

---
## [3] External Resources *(opens in new tab)*

<div class="grid cards" markdown>

-   [**:octicons-arrow-right-24: Mars QuickMap**](https://mars.quickmap.io/layers?prjExtent=-16435210.8833828%2C-8021183.5691341%2C12908789.1166172%2C7866816.4308659&showGraticule=true&layers=NrBMBoAYvBGcQGYAsA2AHHGkB0BOcAOwFcAbU8AbwCIAzUgSwGMBrAUwCdqAuWgQ1IBnNgF8AumKrixQA&proj=3&time=2024-11-11T07%3A09%3A37.723Z){target="_blank"}

    <figure markdown="span">
        [![](https://files.catbox.moe/1k9fb8.png){ width="200" }](https://files.catbox.moe/1k9fb8.png){target="_blank"}
    </figure>

    Lightweight and interactive map of Mars with various datasets and basics GIS tools, completely in your browser! This is my go-to for quick visaualizations and data exploration.

-   [**:octicons-arrow-right-24: PySHTools "Tutorials & Guides"**](https://shtools.github.io/SHTOOLS/python-examples.html){target="_blank"}

    <figure markdown="span">
        [![](https://files.catbox.moe/zlzwgk.png){ width="200" }](https://shtools.github.io/SHTOOLS/python-examples.html){target="_blank"}
    </figure>

    Python package for spherical harmonic computation/analysis in planetary sciences.

</div>
